// Functie om een verborgen inputveld te creëren of te updaten
function updateOrCreateHiddenInput(form, name, value) {
    let hiddenInput = form.querySelector(`input[name="${name}"]`);
    if (!hiddenInput) {
        hiddenInput = document.createElement('input');
        hiddenInput.type = 'hidden';
        hiddenInput.name = name;
        form.appendChild(hiddenInput);
    }
    hiddenInput.value = value;
}

// Voeg event listeners toe op basis van de context van het formulier
document.addEventListener('DOMContentLoaded', function() {
    const forms = document.querySelectorAll('form');

    forms.forEach(function(form) {
        form.addEventListener('submit', function(event) {
            const inputElements = this.querySelectorAll('[data-input-name]');
            inputElements.forEach((inputElement) => {
                const inputName = inputElement.getAttribute('data-input-name');
                const isChecked = inputElement.checked;
                updateOrCreateHiddenInput(this, inputName, isChecked ? 'true' : 'false');
            });
        });

        const checkboxes = form.querySelectorAll('.dynamicCheckbox');
        checkboxes.forEach(function(checkbox) {
            checkbox.addEventListener('change', function() {
                const checkboxName = this.getAttribute('data-input-name');
                const isChecked = this.checked;
                updateOrCreateHiddenInput(form, checkboxName, isChecked ? 'true' : 'false');

                if (this.classList.contains('submitOnToggle')) {
                    form.submit();
                }
            });
        });
    });
});
