<?php

namespace MintySupport\Classes\Controllers;

use MintySupport\Classes\Core\Controllers\BaseController;
use MintySupport\Classes\Core\Managers\AdminPageManager;
use MintySupport\Classes\Core\Managers\SettingsManager;
use MintySupport\Classes\MintySupportBase;

class AdminMenuController extends BaseController {
	public function init(): void {
		add_action( 'admin_menu', [ $this, 'addAdminPage' ] );
	}

	public function addAdminPage(): void {
		// Add your admin page
		$mintyLogoSVG = 'data:image/svg+xml;base64,' . base64_encode('
<svg xmlns="http://www.w3.org/2000/svg" xmlns:xlink="http://www.w3.org/1999/xlink" id="Laag_1" x="0px" y="0px" viewBox="0 0 31.4 20.9" style="enable-background:new 0 0 31.4 20.9;" xml:space="preserve">
  <g id="Group_380" transform="translate(-122 -34)">
    <g id="MM_logo_rgb" transform="translate(84.52 -10.34)">
      <g id="Group_385">
        <path id="Path_2" fill="#0120A0" d="M54.2,51.4c-3.4,3.8-5.2,8.7-5.2,13.8h10.4C59.4,60.1,57.6,55.2,54.2,51.4"></path>
        <path id="Path_2_00000109713291072173348850000016778573350282747022_" fill="#0120A0" d="M53.2,51.4c-3.4,3.8-5.9,8.7-5.9,13.8 h11.1C58.5,60.1,56.6,55.2,53.2,51.4"></path>
        <path id="Path_3" fill="#5E21E5" d="M68.9,65.2V44.3c-6,0-11.7,2.6-15.7,7.1c3.4,3.8,5.2,8.7,5.2,13.8H68.9L68.9,65.2z"></path>
        <path id="Path_4" fill="#02F8B2" d="M53.2,51.4c-4-4.5-9.7-7.1-15.7-7.1v20.9h10.4C48,60.1,49.9,55.2,53.2,51.4"></path>
      </g>
    </g>
  </g>
</svg>
');


		add_menu_page(
			'Minty Support Instellingen',
			'Minty Support',
			'manage_options',
			'minty-support',
			[ $this, 'getSettingsPage' ],
			$mintyLogoSVG,
		);
	}

	public function getSettingsPage(): void {
		$settingsPageServices = AdminPageManager::getInstance();
		$settingsDataServices = SettingsManager::getInstance();
		$adminPageList        = $settingsPageServices->getAdminPages();
		// Haal de juiste pagina op vanuit de page query, als deze niet bestaat, pak de default
		$getPage     = ( isset( $_GET['tab'], $adminPageList[ $_GET['tab'] ] ) ) ? $_GET['tab'] : "default";
		$currentPage = $adminPageList[ $getPage ];

		// Als post request gestuurd is
		if ( $currentPage->getOnSaveTrigger() ) {
			$currentPage->onSave( );
		}

		$this->view(
			'Pages/layout/header',
		);

		// Voeg het menu toe aan de pagina
		$this->view(
			'Pages/layout/menu',
			[
				'currentPage'   => $currentPage,
				'adminPages' => $adminPageList,
				'settingEnabled' => $settingsDataServices->getSettings($currentPage->getSettingName(), false),
			]
		);

		// Laad de juiste pagina aan de hand van naam + onLoad
		$this->view(
			'Pages/AdminPages/' . $currentPage->getName(),
			$currentPage->onLoad(  ),
		);

		$this->view(
			'Pages/layout/footer',
		);
	}
}
