<?php

namespace MintySupport\Classes\Controllers;

use MintySupport\Classes\Core\Controllers\BaseController;
use MintySupport\Classes\Database\Migrations\MintySupportSettingsTable;

class MigrationController extends BaseController {
	private string $migrationsTableName = "minty_support_migrations";

	private array $migrations = [
		// Add the migration classes here
		MintySupportSettingsTable::class,
	];

	public function init(): void {
		// Activeer de migraties bij het activeren van de plugin
		register_activation_hook( MINTY_SUPPORT_PLUGIN_FILE, [ $this, 'runMigrations' ] );
	}

	public function runMigrations(): void {
		global $wpdb;
		$tableName = $wpdb->prefix . $this->migrationsTableName;
		// Kijk of de migratietabel bestaat, zo niet maak deze aan
		if ( $wpdb->get_var( "show tables like '$tableName'" ) != $tableName ) {
			$this->createMigrationsTable();
		}


		foreach ( $this->migrations as $migrationClass ) {
			$migration     = new $migrationClass();
			$migrationName = $migration->getName();
			$sql           = "SELECT * FROM $tableName WHERE migration = '$migrationName';";

			// Als de migratie nog niet is uitgevoerd, voer deze dan uit
			if ( empty( $wpdb->get_results( $sql ) ) ) {
				$wpdb->get_results( $migration->statement() );
				$this->saveMigration( $migration->getName() );
			}
		}
	}

	// Sla de migratie op in de database
	private function saveMigration( string $migrationName ): void {
		global $wpdb;
		$tableName = $wpdb->prefix . $this->migrationsTableName;
		$wpdb->get_results( "INSERT INTO `$tableName` (migration) VALUES ('$migrationName')" );
	}

	private function createMigrationsTable(): void {
		global $wpdb;
		$tableName = $wpdb->prefix . $this->migrationsTableName;

		$sql = "CREATE TABLE `" . $tableName . "`  ( 
                `id`  int  NOT NULL auto_increment, 
                `migration` varchar(255), 
                PRIMARY KEY (id) 
            );";

		$wpdb->get_results( $sql );
	}
}