<?php

namespace MintySupport\Classes\Core\Managers;

use MintySupport\Classes\Core\Settings\BaseAdminSettingsPage;
use MintySupport\Classes\Modules\GeneralSettings\AdminPages\DefaultBase;
use MintySupport\Classes\Modules\PostTypesOrder\AdminPages\PostTypesBase;
use MintySupport\Classes\Modules\SmtpMail\AdminPages\SmtpMailBase;
use MintySupport\Classes\Modules\TemporarilyLogin\AdminPages\TemporarilyLogin;

class AdminPageManager {

	private static ?AdminPageManager $_instance = null;

	/**
	 * @var BaseAdminSettingsPage[] $adminPages Array van objecten die afstammen van de BaseAdminSettingsPage class.
	 */
	private array $adminPages = [];

    private function adminPagesList(): array {
	    return [
		    DefaultBase::class,
		    PostTypesBase::class,
		    TemporarilyLogin::class,
		    SmtpMailBase::class,
	    ];
    }

	public function __construct() {
		$this->loadPages();
	}

	public function loadPages(): void {
		foreach ( $this->adminPagesList() as $page ) {
			$settingsPageInstance = new $page();
			if ( ! ( $settingsPageInstance instanceof BaseAdminSettingsPage ) ) {
				continue;
			}
			$this->adminPages[ $settingsPageInstance->getName() ] = $settingsPageInstance;
		}
	}

	public function getAdminPages(): array {
		return $this->adminPages;
	}

	public static function getInstance(): AdminPageManager
	{
		if(self::$_instance === null) {
			self::$_instance = new self();
		}
		return self::$_instance;
	}
}
