<?php

namespace MintySupport\Classes\Core\Managers;

use Exception;
use MintySupport\Classes\Core\Modules\Module;
use MintySupport\Classes\Modules\GeneralSettings\GeneralSettingsModule;
use MintySupport\Classes\Modules\MintyWooMiniCart\MintyWooMiniCartModule;
use MintySupport\Classes\Modules\PostTypesOrder\PostTypesOrderModule;
use MintySupport\Classes\Modules\SmtpMail\SmtpMailModule;
use MintySupport\Classes\Modules\TemporarilyLogin\TemporarilyLoginModule;

class ModuleManager {
	private static ?ModuleManager $_instance = null;

	/** @var Module[] $modules */
	private array $modules = [];

	private array $moduleClasses = [
		GeneralSettingsModule::class,
		MintyWooMiniCartModule::class,
		PostTypesOrderModule::class,
		TemporarilyLoginModule::class,
		SmtpMailModule::class,
	];


	/**
	 * @throws Exception
	 */
	private function __construct() {
		$this->init();
	}


	/**
	 * @return void
	 * @throws Exception
	 */
	private function init(): void {
		$settingsManager = SettingsManager::getInstance();
		foreach ( $this->moduleClasses as $module ) {
			if ($module::getName() !== 'general_settings' && $settingsManager->getSettings($module::getName(), 'false') === 'false') {
				continue;
			}

			$instance = new $module();
			if ( ! ( $instance instanceof Module ) ) {
				throw new Exception( "Module $instance does not extend {MintySupport\Classes\Core\Modules\Module}" );
			}

			$this->register( $instance );
		}
	}

	public function register( Module $module ): void {
		$this->modules[ $module::getName() ] = $module;
		$module->init();
	}

	/**
	 * @param string $name
	 *
	 * @return bool
	 */
	public function exists( string $name ): bool {
		return array_key_exists( $name, $this->modules );
	}

	/**
	 * @param string $name
	 *
	 * @return Module
	 */
	public function get( string $name ): Module {
		return $this->modules[ $name ];
	}

	/**
	 * @return Module[]
	 */
	public function getModules(): array {
		return $this->modules;
	}

	/**
	 * @return ModuleManager
	 */
	public static function getInstance(): ModuleManager {
		if ( self::$_instance === null ) {
			self::$_instance = new ModuleManager();
		}

		return self::$_instance;
	}
}
