<?php

namespace MintySupport\Classes\Core\Managers;


class SettingsManager {
	private static ?SettingsManager $_instance = null;
	private ?array $settings;
	public static function getTableName(): string {
		global $wpdb;

		return $wpdb->prefix . "minty_support_settings";
	}

	public function __construct() {
		$this->loadSettings();
	}

	public function getSettings( string $settingName, $notFound = null ) {
		return $this->settings[$settingName] ?? $notFound;
	}

	public function getAllSettings(): array {
		return $this->settings;
	}

	public function setSetting( $settingName, $settingValue ): void {
		$this->settings[ $settingName ] = $settingValue;
	}


	public function save(): void {
		global $wpdb;
		$tableName = self::getTableName();

		foreach ( $this->settings as $name => $value ) {
			$checkingSql = $wpdb->prepare( "SELECT setting_name, setting_value FROM `$tableName` WHERE setting_name = '%s' ", $name );
			$data        = $wpdb->get_results( $checkingSql );

			$updatingSql = ! empty( $data )
				? "UPDATE $tableName SET setting_value = %s WHERE setting_name = %s "
				: "INSERT INTO $tableName ( setting_value, setting_name) values (%s, %s)";

			$prepSQL = $wpdb->prepare( $updatingSql, [ $value, $name ] );
			$wpdb->get_results( $prepSQL );
		}
	}

	private function loadSettings(): void {
		global $wpdb;
		$tableName   = self::getTableName();
		$getSettings = $wpdb->get_results( "SELECT setting_name, setting_value FROM `$tableName`" );

		// Als er geen settings zijn, dan is er niets te laden
		if ( ! $getSettings ) {
			$this->settings = [];
			return;
		}

		foreach ( $getSettings as $getSetting ) {
			$this->settings[ $getSetting->setting_name ] = $getSetting->setting_value;
		}
	}

	public static function getInstance(): SettingsManager
	{
		if(self::$_instance === null) {
			self::$_instance = new self();
		}

		return self::$_instance;
	}
}
