<?php

namespace MintySupport\Classes\Core\Settings;

use MintySupport\Classes\Core\Managers\EncryptManager;
use MintySupport\Classes\Core\Managers\SettingsManager;
use MintySupport\Classes\Modules\SmtpMail\MailProviders\GoogleProvider;
use MintySupport\Classes\Modules\SmtpMail\MailProviders\MicrosoftProvider;

abstract class BaseAdminSettingsPage {
	abstract public function getName(): string;

	public function getSettingName(): string {
		return "";
	}

	abstract public function getDisplayName(): string;


	public function onLoad(): array {
		return [];
	}

	public function onSave(): bool {
		$settingsServices = SettingsManager::getInstance();
		$allSettings      = $settingsServices->getAllSettings();
		$updateSettings   = false;


		if ($_POST['action'] === 'send_minty_test_mail') {
			$upload_dir = wp_upload_dir(); // Verkrijg de uploads-directory
			$attachment = $upload_dir['basedir'] . '/test.pdf'; // Pad naar de bijlage
			$to = sanitize_email($_POST['mail_test_email']);
			$subject = "Test onderwerp";
			$message = "Test bericht!";

			// Test met bijlage
			if (file_exists($attachment)) {
				$mailSent = wp_mail($to, $subject, $message, '', $attachment);

			} else {
				$mailSent = wp_mail($to, $subject, $message);
			}

			if ($mailSent) {
				echo '<div class="notice notice-success is-dismissible"><p>Testmail succesvol verzonden!</p></div>';
			} else {
				echo $_SESSION['minty_mail_error_message'];
			}

			if (isset($_SESSION['minty_mail_error_message'])) {
				return false;
			}

			return true;
		}

		if ($_POST['action'] === 'remove_minty_client_tokens') {
			$selectedTab = $settingsServices->getSettings('smtp_mail_tab_selected');

			$providers = [
				'microsoft' => MicrosoftProvider::class,
				'google' => GoogleProvider::class,
			];

			// Controleer of het geselecteerde tabblad een geldige provider heeft
			if (isset($providers[$selectedTab])) {
				$providerClass = $providers[$selectedTab];
				$provider = new $providerClass();
				$provider->removeTokens();
			}

			return true;
		}

		if ($_POST['action'] === 'save_minty_temp_user') {
			$this->saveTempUser();
			return true;
		}

		if ($_POST['action'] === 'delete_minty_temp_user') {
			$this->deleteTempUser();
			return true;
		}

		if ($_POST['action'] === 'save_minty_google_settings') {
			$this->saveGoogleSettings();
			return true;
		}

		foreach ($this->getPostedSettings() as $key) {
			if (!isset($_POST[$key])) {
				continue;
			}

			// Aangepaste logica voor het versleutelen van het mailwachtwoord
			if ($key === 'mail_password') {
				$encryptServices = EncryptManager::getInstance();
				$postedValue     = $encryptServices->encryptData($_POST[$key]);
			} else {
				$postedValue = sanitize_text_field($_POST[$key]);
			}

			if (!isset($postedValue)) {
				continue;
			}

			if (array_key_exists($key, $allSettings) && $postedValue === $allSettings[$key]) {
				continue;
			}

			$settingsServices->setSetting($key, $postedValue);
			$updateSettings = true;
		}

		if ($updateSettings) {
			$settingsServices->save();
			echo '<div class="notice notice-success is-dismissible"><p>Instellingen succesvol opgeslagen!</p></div>';
		}

		return true;
	}


	private function saveGoogleSettings(): void {
		if ( !isset( $_FILES['google_mail_json_details'] ) ) {
			$_SESSION['minty_mail_error_message'] = 'Er is geen bestand geüpload.';
			return;
		}

		$uploadedFile = $_FILES['google_mail_json_details']['tmp_name'];

		// Controleer of het bestand daadwerkelijk een JSON-bestand is
		if ( $_FILES['google_mail_json_details']['type'] !== 'application/json' ) {
			$_SESSION['minty_mail_error_message'] = 'Het geüploade bestand is geen JSON-bestand.';
			return;
		}

		// Lees de JSON-gegevens uit het bestand
		$jsonData    = file_get_contents( $uploadedFile );
		$credentials = json_decode( $jsonData, true, 512, JSON_THROW_ON_ERROR );

		if ( json_last_error() !== JSON_ERROR_NONE ) {
			$_SESSION['minty_mail_error_message'] = 'Het geüploade bestand is geen geldig JSON-bestand.';
			return;
		}

		// Haal de benodigde gegevens uit de JSON
		$clientId     = $credentials['web']['client_id'] ?? null;
		$clientSecret = $credentials['web']['client_secret'] ?? null;
		$redirectUri   = ( isset( $_SERVER['HTTPS'] ) && $_SERVER['HTTPS'] === 'on' ? 'https' : 'http' ) . '://' . $_SERVER['HTTP_HOST'] . '/wp-admin/';

		// Controleer of de benodigde gegevens aanwezig zijn
		if ( ! $clientId || ! $clientSecret ) {
			// Geef een foutmelding als gegevens ontbreken
			$_SESSION['minty_mail_error_message'] = 'De geüploade JSON bevat niet alle benodigde gegevens.';
			return;
		}

		// Sla de gegevens op in de settings
		$settingsServices = SettingsManager::getInstance();
		$settingsServices->setSetting( 'google_client_id', $clientId );
		$settingsServices->setSetting( 'google_client_secret', $clientSecret );
		$settingsServices->setSetting( 'google_redirect_uri', $redirectUri );
		$settingsServices->save();
		echo '<div class="notice notice-success is-dismissible"><p>Instellingen succesvol opgeslagen!</p></div>';
	}


	public function getOnSaveTrigger(): bool {
		return ( ! empty( $_POST ) && isset( $_POST['action'] ) && $_POST['action'] === 'save_minty_support_settings' );
	}
}