<?php

namespace MintySupport\Classes\Core\Templates;

use MintySupport\Classes\MintySupportBase;

class TemplateService
{



    private static ?TemplateService $_instance = null;

    protected string $templateRootPath = "Templates/";


    /**
     * Load a template.
     *
     * @param string $templateName The name of the template to load.
     * @param array $vars The variables to be passed to the template (default: []).
     * @param string|null $templateRootPath The root path of the templates (default: null).
     * @return bool Returns true if the template is successfully loaded, otherwise false.
     */
    public function load(string $templateName, array $vars = [], ?string $templateRootPath = null): bool
    {
        $templateRootPath ??= $this->templateRootPath;
        $templatePath = $this->formatTemplatePath($templateName, $templateRootPath);

        if(!file_exists($templatePath)) {
            return false;
        }

        $this->renderTemplate($templatePath, $vars);

        return true;
    }


    /**
     * Render a template.
     *
     * @param string $templatePath The path to the template file.
     * @param array $vars The variables to be passed to the template (default: []).
     * @return void
     */
    private function renderTemplate(string $templatePath, array $vars = []): void
    {
        extract($vars);
        require $templatePath;
    }

    /**
     * Formats the template the file path to a normal directory structure
     * @param string $formattedPath
     * @param string $templateRootPath
     * @return string
     */
    private function formatTemplatePath (string $formattedPath, string $templateRootPath) : string {

        $formattedPath = str_replace(["."], "/" ,$formattedPath);
        $fullPath = MintySupportBase::getPluginDir().$templateRootPath;
        return $fullPath.$formattedPath. ".php";
    }


    public static function getInstance (): ?TemplateService {
        if(self::$_instance === null) {
            self::$_instance = new self();
        }

        return self::$_instance;
    }
}
