<?php

namespace MintySupport\Classes\Core\Wordpress;

use MintySupport\Classes\MintySupportBase;

abstract class Script {
	public function init(): void {
		$enqueue = $this->getIsAdmin() ? "admin_enqueue_scripts" : "wp_enqueue_scripts";


		if ( $this->loadOnWpLoad() ) {
			add_action('wp_loaded', [$this, 'conditionalEnqueue']);
		} else {
			$this->conditionalEnqueue($enqueue);
		}

	}

	public function conditionalEnqueue($enqueue): void {
		add_action( $enqueue, function () {
			// Controleer of de script geladen moet worden
			if ( ! $this->shouldLoad() ) {
				return;
			}
			$this->registerAndEnqueueScript();
		} );
	}

	private function loadOnWpLoad(): bool {
		return false;
	}

	private function registerAndEnqueueScript(): void {
		wp_register_script( $this->getName(), MintySupportBase::getPluginUrl() . $this->getFile() );

		if ( $this->getVarsName() && $this->getVars() ) {
			wp_localize_script( $this->getName(), $this->getVarsName(), $this->getVars() );
		}

		wp_enqueue_script( $this->getName(), "", [], null, $this->getIsFooter() );
	}

	abstract public function getName(): string;

	abstract public function getFile(): string;

	abstract public function getVarsName(): string;

	abstract public function getVars(): array;

	public function shouldLoad(): bool {
		return true;
	}

	public function getIsFooter(): bool {
		return false;
	}

	public function getIsAdmin(): bool {
		return true;
	}
}