<?php

namespace MintySupport\Classes;

use Exception;
use MintySupport\Classes\Controllers\ActionController;
use MintySupport\Classes\Controllers\AdminMenuController;
use MintySupport\Classes\Controllers\EndpointController;
use MintySupport\Classes\Controllers\FilterController;
use MintySupport\Classes\Controllers\MigrationController;
use MintySupport\Classes\Controllers\PageController;
use MintySupport\Classes\Controllers\ScriptController;
use MintySupport\Classes\Controllers\ShortcodeController;
use MintySupport\Classes\Core\Controllers\BaseController;

class MintySupportBase {
	private static ?MintySupportBase $_instance = null;

	public static function getInstance(): MintySupportBase {
		null === self::$_instance and self::$_instance = new self;

		return self::$_instance;
	}

	/**
	 * Constructor.
	 */
	private function __construct() {
		$controllers = [
			MigrationController::class,
			AdminMenuController::class,
			PageController::class,
			EndpointController::class,
			ScriptController::class,
			ShortcodeController::class,
			ActionController::class,
			FilterController::class,
		];


		foreach ( $controllers as $controller ) {
			$controllerInstance = new $controller();
			if(!($controllerInstance instanceof BaseController)) {
				throw new Exception( "Controller $controllerInstance does not extend {MintySupport\Classes\Core\Controllers\BaseController.php}" );
			}


			$controllerInstance->init();
		}
	}

	public static function getPluginDir ():string {
		return plugin_dir_path(MINTY_SUPPORT_PLUGIN_FILE);
	}

	public static function getPluginUrl(): string {
		return plugin_dir_url( MINTY_SUPPORT_PLUGIN_FILE );
	}

	public static function getPostTypes(): array {
		$args     = array(
			'public' => true,
		);
		$output   = 'names';
		$operator = 'and';

		return get_post_types( $args, $output, $operator );
	}
}
