<?php

namespace MintySupport\Classes\Modules\GeneralSettings\Actions;

use MintySupport\Classes\Core\Managers\SettingsManager;
use MintySupport\Classes\Core\Wordpress\Action;

class ProductCategorySlug extends Action {

	public function getHooks(): array {
		return [
			'init'
		];
	}

	public function execute(): void {
		$settings = SettingsManager::getInstance();
		$enabled  = $settings->getSettings('category_pagination_slug_enabled');

		$isWooCommerceActive = in_array('woocommerce/woocommerce.php', apply_filters('active_plugins', get_option('active_plugins')), true);

		if (!$isWooCommerceActive) {
			if ($enabled === 'true') {
				$settings->setSetting('category_pagination_slug_enabled', 'false');
				$settings->save();
			}
			return;
		}

		if ($enabled === 'true') {
			add_filter('request', [$this, 'removeProductCategorySlug']);
			add_filter('term_link', [$this, 'termLinkFilter'], 10, 3);
		}
	}


	public function removeProductCategorySlug( $vars ): array {
		global $wpdb;

		if (isset($vars['error'])) {
			$lastVar = basename($_SERVER['REQUEST_URI']);
			$vars['attachment'] = $lastVar;
		}

		$slug = $vars['pagename'] ?? $vars['name'] ?? $vars['category_name'] ?? $vars['attachment'] ?? null;

		if (!$slug) {
			return $vars;
		}

		$exists = $wpdb->get_var($wpdb->prepare(
			"SELECT t.term_id FROM $wpdb->terms t 
        LEFT JOIN $wpdb->term_taxonomy tt ON tt.term_id = t.term_id 
        WHERE tt.taxonomy = 'product_cat' AND t.slug = %s",
			$slug
		));

		if (!$exists) {
			return $vars;
		}

		$oldVars = $vars;
		$vars = ['product_cat' => $slug];

		if (!empty($oldVars['paged']) || !empty($oldVars['page'])) {
			$vars['paged'] = $oldVars['paged'] ?? $oldVars['page'];
		}

		if (!empty($oldVars['orderby'])) {
			$vars['orderby'] = $oldVars['orderby'];
		}

		if (!empty($oldVars['order'])) {
			$vars['order'] = $oldVars['order'];
		}

		return $vars;
	}


	public function termLinkFilter( string $url, $term, string $taxonomy ): string {
		if ($taxonomy !== 'product_cat') {
			return $url;
		}

		$categoryBase = get_option('woocommerce_permalinks')['category_base'];

		if (!$categoryBase) {
			return $url;
		}

		return str_replace('/' . $categoryBase . '/', '/', $url);
	}
}