<?php

namespace MintySupport\Classes\Modules\MintyWooMiniCart\Endpoints;

use MintySupport\Classes\Core\Endpoints\AjaxEndpoint;

class RemoveCartItemEndpoint extends AjaxEndpoint {

	public static function getRouteName(): string {
		return "minty_woo_cart_remove_item";
	}

	public static function getRequestType(): string {
		return self::$Post;
	}

	public function handle( object|array $requestData ): void {
		$this->validateAndSanitizeRequest( $requestData );

		$cartItemKey = $requestData['cartKey'];

		// Check if cart item exists
		if ( ! WC()->cart->find_product_in_cart( $cartItemKey ) ) {
			$this->setErrorRes( 400, 'Item not found in cart' );
		}

		// Update cart items quantity
		WC()->cart->remove_cart_item( $cartItemKey );
		$this->setSuccessRes( 'Item removed from cart' );
	}


	private function validateAndSanitizeRequest( $request ): void {
		$requiredFields = [
			'cartKey',
		];

		foreach ( $requiredFields as $field ) {
			if ( ! isset( $request[ $field ] ) ) {
				$this->setErrorRes( 400, 'Something is missing from the request!' );
			}
		}
	}
}