<?php

namespace MintySupport\Classes\Modules\MintyWooMiniCart\Endpoints;

use MintySupport\Classes\Core\Endpoints\AjaxEndpoint;

class UpdateCartItemQuantityEndpoint extends AjaxEndpoint {

	public static function getRouteName(): string {
		return "minty_woo_cart_update_item_quantity";
	}

	public static function getRequestType(): string {
		return self::$Post;
	}

	public function handle( object|array $requestData ): void {
		$this->validateAndSanitizeRequest( $requestData );

		$cartItemKey = $requestData['cartKey'];
		$quantity    = $requestData['quantity'];

		// Check if cart item exists
		if ( ! WC()->cart->find_product_in_cart( $cartItemKey ) ) {
			$this->setErrorRes( 400, 'Item not found in cart' );
		}

		// Update cart items quantity
		WC()->cart->set_quantity( $cartItemKey, $quantity, true );
		$this->setSuccessRes( 'Item quantity updated' );
	}


	private function validateAndSanitizeRequest( $request ): void {
		$requiredFields = [ 'cartKey', 'quantity' ];

		foreach ( $requiredFields as $field ) {
			if ( ! isset( $request[ $field ] ) ) {
				$this->setErrorRes( 400, 'Something is missing from the request!' );
			}
		}

		$quantity    = absint( $request['quantity'] );

		if ( $quantity < 1 ) {
			$this->setErrorRes( 400, 'Invalid quantity' );
		}

	}
}