<?php

namespace MintySupport\Classes\Modules\MintyWooMiniCart;



use MintySupport\Classes\Core\Managers\SettingsManager;
use MintySupport\Classes\Core\Modules\Module;
use MintySupport\Classes\Modules\MintyWooMiniCart\Endpoints\GetLatestCartDataEndpoint;
use MintySupport\Classes\Modules\MintyWooMiniCart\Endpoints\RemoveCartItemEndpoint;
use MintySupport\Classes\Modules\MintyWooMiniCart\Endpoints\UpdateCartItemQuantityEndpoint;
use MintySupport\Classes\Modules\MintyWooMiniCart\Scripts\MintyWooCartApi;
use MintySupport\Classes\Modules\MintyWooMiniCart\Scripts\MintyWooMiniCart;
use MintySupport\Classes\Modules\MintyWooMiniCart\Shortcodes\MintyShoppingCartShortcode;

class MintyWooMiniCartModule extends Module {

	public static function getName(): string {
		return "minty_woo_mini_cart";
	}

	public function init(): bool {
		return true;
	}

	public function getScripts(): array {
		return [
			MintyWooCartApi::class,
			MintyWooMiniCart::class,
		];
	}

	public function getEndpoints(): array {
		$isWooCommerceActive = in_array('woocommerce/woocommerce.php', apply_filters('active_plugins', get_option('active_plugins')), true);
		if (!$isWooCommerceActive) {
			$settingsManager = SettingsManager::getInstance();
			$settingsManager->setSetting(self::getName(), 'false');
			$settingsManager->save();
		}

		return [
			GetLatestCartDataEndpoint::class,
			UpdateCartItemQuantityEndpoint::class,
			RemoveCartItemEndpoint::class,
		];
	}

	public function getShortcodes(): array {
		return [
			MintyShoppingCartShortcode::class
		];
	}

}
