<?php

namespace MintySupport\Classes\Modules\PostTypesOrder\Endpoints;

use MintySupport\Classes\Core\Endpoints\AjaxEndpoint;

class SavePostsOrderEndpoint extends AjaxEndpoint {

	public static function getRouteName(): string {
		return "minty_save_posts_order";
	}

	public static function getRequestType(): string {
		return self::$Post;
	}

	public function handle(object|array $requestData): void {
		if (!current_user_can('edit_posts')) {
			$this->setErrorRes(403, 'Permission denied');
		}
		$order = $requestData["order"] ?? [];

		if (empty($order)) {
			$this->setErrorRes(400, 'No order data received');
		}

		$success = true;

		// Loop door de ontvangen volgorde en update de menu_order voor elk bericht
		foreach ($order as $item) {
			$postId = $item['id'];
			$position = $item['position'];

			$result = wp_update_post(array(
				'ID'         => $postId,
				'menu_order' => $position,
			));

			if (is_wp_error($result)) {
				$this->setErrorRes(500, 'Error updating post: ' . $result->get_error_message());
			}

			if (!$result) {
				$success = false;
				break;
			}
		}

		if ($success) {
			$this->setSuccessRes('Order saved successfully');
		} else {
			$this->setErrorRes(500, 'Failed to save order');
		}
	}
}