<?php

namespace MintySupport\Classes\Modules\SmtpMail\Actions;

use MintySupport\Classes\Core\Managers\SettingsManager;
use MintySupport\Classes\Core\Wordpress\Action;
use MintySupport\Classes\Modules\SmtpMail\MailProviders\GoogleProvider;
use MintySupport\Classes\Modules\SmtpMail\MailProviders\MicrosoftProvider;

class HandleOAuthResponse extends Action {

	public function getHooks(): array {
		return [
			'admin_init'
		];
	}

	public function execute(): void {
		$settingsData = SettingsManager::getInstance();

		$oauthCode = $_GET['code'] ?? null;
		$selectedTab = $settingsData->getSettings('smtp_mail_tab_selected', 'standaard');

		$providers = [
			'microsoft' => MicrosoftProvider::class,
			'google' => GoogleProvider::class,
		];

		if (!$oauthCode || !isset($providers[$selectedTab])) {
			return;
		}

		if ($selectedTab === 'microsoft') {
			$microsoftAccessToken = $settingsData->getSettings('microsoft_mail_access_token', false);
			if ($microsoftAccessToken) {
				return;
			}
		}

		if ($selectedTab === 'google') {
			$googleAccessToken = $settingsData->getSettings('google_access_token', false);
			if ($googleAccessToken) {
				return;
			}
		}

		$providerClass = $providers[$selectedTab];
		$provider = new $providerClass();
		$provider->handleOAuth();
	}
}