<?php

namespace MintySupport\Classes\Modules\SmtpMail\Actions;

use MintySupport\Classes\Core\Managers\SettingsManager;
use MintySupport\Classes\Core\Wordpress\Action;
use MintySupport\Classes\Modules\SmtpMail\MailProviders\GoogleProvider;
use MintySupport\Classes\Modules\SmtpMail\MailProviders\MicrosoftProvider;
use MintySupport\Classes\Modules\SmtpMail\MailProviders\SMTPProvider;
use PHPMailer\PHPMailer\PHPMailer;

class PhpMailerInit extends Action {

	/**
	 * Returns the hooks to be registered for this action.
	 *
	 * @return array
	 */
	public function getHooks(): array {
		return [
			'phpmailer_init'
		];
	}

	/**
	 * Executes the action, setting up the PHPMailer instance with the selected provider.
	 *
	 * @param PHPMailer $phpmailer The PHPMailer instance to be configured.
	 */
	public function execute(PHPMailer $phpmailer): void {
		$settingsData = SettingsManager::getInstance();
		$selectedTab = $settingsData->getSettings('smtp_mail_tab_selected', 'standaard');
		$providers = [
			'microsoft' => MicrosoftProvider::class,
			'google' => GoogleProvider::class,
			'standaard' => SMTPProvider::class,
		];

		// Use the selected provider or default to SMTPProvider.
		$providerClass = $providers[$selectedTab] ?? SMTPProvider::class;
		$provider = new $providerClass();
		$provider->setup($phpmailer);

	}
}
