<?php

namespace MintySupport\Classes\Modules\SmtpMail\MailProviders;

use Exception;
use MintySupport\Classes\Core\Managers\EncryptManager;
use MintySupport\Classes\Core\Managers\SettingsManager;
use MintySupport\Classes\Core\Settings\MailProviders\ProviderBase;
use PHPMailer\PHPMailer\PHPMailer;

class SMTPProvider extends ProviderBase {

	public function setup(PHPMailer $phpmailer): void {
		try {
			$encryptServices = EncryptManager::getInstance();
			$settingsData    = SettingsManager::getInstance();
			$phpmailer->isSMTP();
			$phpmailer->Host       = $settingsData->getSettings( 'mail_host', false );
			$phpmailer->SMTPAuth   = true;
			$phpmailer->Username   = $settingsData->getSettings( 'mail_username', false );
			$phpmailer->Password   = $encryptServices->decryptData( $settingsData->getSettings( 'mail_password', false ) );
			$phpmailer->SMTPSecure = $settingsData->getSettings( 'mail_security', false );
			$phpmailer->Port       = $settingsData->getSettings( 'mail_port', false );

			// Optioneel: extra configuratie
			$phpmailer->From     = $settingsData->getSettings( 'mail_sender_email', false );
			$phpmailer->FromName = $settingsData->getSettings( 'mail_sender_name', false );

			// Probeer een verbinding te maken om de SMTP-instellingen te verifiëren
			if ( ! $phpmailer->smtpConnect() ) {
				throw new \RuntimeException( 'Kon niet verbindden met de SMTP server.' );
			}
		} catch ( Exception $e ) {
			error_log( 'Fout: ' . $e->getMessage() );
			return;
		}

		try {
			$phpmailer->send();
			$_SESSION['has_email_send_minty'] = true;
		} catch ( Exception $e ) {
			error_log( 'Fout: ' . $e->getMessage() );
			$_SESSION['has_email_send_minty'] = false;
			return;
		}

	}
}