<?php

namespace MintySupport\Classes\Modules\SmtpMail\PhpMailAdapters;

use Exception;
use Google\Client as Google_Client;
use Google\Service\Gmail as Google_Service_Gmail;
use Google\Service\Gmail\Message as Google_Service_Gmail_Message;
use MintySupport\Classes\Core\Managers\SettingsManager;
use PHPMailer\PHPMailer\PHPMailer;

class GoogleMailAdapter extends PHPMailer {
	private string $accessToken;
	private PHPMailer $phpMailer;
	private SettingsManager $settingsServices;

	public function __construct(PHPMailer $phpMailer, $accessToken) {
		parent::__construct();
		$this->phpMailer   = $phpMailer;
		$this->accessToken = $accessToken;
		$this->settingsServices = SettingsManager::getInstance();
		$this->overridePhpMailer();
		$this->send();
	}

	/**
	 * @throws \PHPMailer\PHPMailer\Exception
	 */
	private function overridePhpMailer(): void {
		$this->phpMailer->Sender   = '';
		$this->phpMailer->isSMTP();
		if ($this->settingsServices->getSettings('force_mail_sender_name') === 'true') {
			$fullName = $this->settingsServices->getSettings('mail_sender_name', false);
		} else {
			$fullName = $this->settingsServices->getSettings('google_client_fullname', false);
		}
		if ($this->settingsServices->getSettings('force_mail_sender_email') === 'true') {
			$email = $this->settingsServices->getSettings('mail_sender_email', false);
		} else {
			$email = $this->settingsServices->getSettings('google_client_username', '');
		}
		$this->phpMailer->From     = $email;
		$this->phpMailer->FromName = $fullName;
		$this->phpMailer->setFrom($email, $fullName);
	}

	public function send(): bool {
		// Bereid de e-mail voor zonder de verzendfunctionaliteit van PHPMailer aan te roepen.
		if (!$this->phpMailer->preSend()) {
			return false;
		}

		// Set up Google Client en verstuur de e-mail via Gmail
		$client = new Google_Client();
		$client->setAccessToken($this->accessToken);
		$service = new Google_Service_Gmail($client);

		// Formatteer de e-mailgegevens
		$rawMessage = $this->createRawMessage();
		$msg = new Google_Service_Gmail_Message();
		$msg->setRaw($rawMessage);

		// Verstuur de e-mail via Google
		try {
			$service->users_messages->send("me", $msg);
			$_SESSION['has_email_send_minty'] = true;
			return true;
		} catch (Exception $e) {
			$_SESSION['minty_mail_error_message'] = $e->getMessage();
			$_SESSION['has_email_send_minty'] = false;
			error_log($e->getMessage());
			return false;
		}
	}


	private function createRawMessage(): string {
		// Base64 encode het bericht zoals Gmail verwacht
		$rawMessage = base64_encode( $this->phpMailer->getSentMIMEMessage());

		return str_replace(['+', '/', '='], ['-', '_', ''], $rawMessage);
	}
}
