<?php

namespace MintySupport\Classes\Modules\SmtpMail\RestApis\Microsoft;

use Exception;
use MintySupport\Classes\Core\Api\RestApi;
use MintySupport\Classes\Core\Managers\SettingsManager;
use MintySupport\Classes\Modules\SmtpMail\MailProviders\MicrosoftProvider;

class MicrosoftGraphRestApi extends RestApi {
	private string $accessToken;

	/**
	 * @throws Exception
	 */
	public function __construct($debug = true ) {
		$this->accessToken    = $this->retrieveAccessToken();
		parent::__construct( $debug );
	}

	public function getBaseUrl(): string {
		return 'https://graph.microsoft.com/';
	}

	public function getDefaultHeaders(): array {
		return [
			'Authorization' => 'Bearer ' . $this->accessToken,
			'Content-Type'  => 'application/json',
			'Accept'        => 'application/json'
		];
	}

	/**
	 * @throws \JsonException
	 */
	private function retrieveAccessToken(): string {
		$settingsData       = SettingsManager::getInstance();
		$currentAccessToken = $settingsData->getSettings( 'microsoft_mail_access_token', false );
		if ( ! $currentAccessToken ) {
			$_SESSION['minty_mail_error_message'] = 'Er is geen geldig access token aanwezig';
			return '';
		}

		$oAuthApi  = new OAuthRestApi();
		$tokenInfo = $oAuthApi->validateAccessToken( $currentAccessToken );
		if ( $tokenInfo->isValid ) {
			return $currentAccessToken;
		}

		if ( empty( $tokenInfo->payload ) ) {
			$_SESSION['minty_mail_error_message'] = 'Geen geldig access token, je moet opnieuw inloggen.';
			$microsoftProvider = new MicrosoftProvider(  );
			$microsoftProvider->removeTokens();
			return '';
		}

		$refreshToken = $settingsData->getSettings( 'microsoft_mail_refresh_token', false );
		$clientId     = $settingsData->getSettings( 'microsoft_mail_application_id', false );
		$clientSecret = $settingsData->getSettings( 'microsoft_mail_application_password', false );

		if ( ! $refreshToken ) {
			$_SESSION['minty_mail_error_message'] = 'Geen refresh token beschikbaar om een nieuw access token aan te vragen.';
			return '';
		}

		$newTokens = $oAuthApi->getRefreshToken( $refreshToken, $clientId, $clientSecret );
		if ( ! $newTokens ) {
			$_SESSION['minty_mail_error_message'] = 'Kon geen nieuw access token verkrijgen met de refresh token.';
			return '';
		}

		$currentAccessToken = $newTokens['access_token'];
		$settingsData->setSetting( 'microsoft_mail_access_token', $currentAccessToken );
		$settingsData->setSetting( 'microsoft_mail_refresh_token', $newTokens['refresh_token'] );
		$settingsData->save();

		return $currentAccessToken;

	}

	public function getUserProfile(): array {
		$response = $this->getRequest( "/v1.0/me" );
		if (!$response) {
			return [];
		}

		return (array) $response;
	}
}

