<?php

namespace MintySupport\Classes\Modules\SmtpMail\RestApis\Microsoft;


use JsonException;
use MintySupport\Classes\Core\Api\RestApi;

class OAuthRestApi extends RestApi {
	public function __construct( $debug = true ) {
		parent::__construct( $debug );
	}

	public function getBaseUrl(): string {
		return 'https://login.microsoftonline.com';
	}

	public function getAccessToken( $clientId, $clientSecret, $code, $redirectUri ): object|bool|array {
		$tokenRequestData = [
			'grant_type'    => 'authorization_code',
			'client_id'     => $clientId,
			'client_secret' => $clientSecret,
			'code'          => $code,
			'redirect_uri'  => $redirectUri
		];

		return $this->postRequest( "/common/oauth2/v2.0/token", $tokenRequestData );
	}

	public function getRefreshToken( $refreshToken, $clientId, $clientSecret ): object|bool|array {
		$postData = [
			'grant_type'    => 'refresh_token',
			'refresh_token' => $refreshToken,
			'client_id'     => $clientId,
			'client_secret' => $clientSecret,
			'scope'         => 'https://graph.microsoft.com/.default',
		];

		return $this->postRequest( "/common/oauth2/v2.0/token", $postData );
	}

	/**
	 * @throws JsonException
	 */
	public function validateAccessToken( $accessToken ): object {
		// Token opsplitsen
		$tokenParts = explode( '.', $accessToken );

		// Controleren of het token het juiste aantal onderdelen heeft (header, payload, signature)
		if ( count( $tokenParts ) !== 3 ) {
			return (object) [
				'isValid' => false,
				'payload' => null
			];
		}

		// Payload decoderen
		$tokenPayload = json_decode( base64_decode( $tokenParts[1] ), true, 512, JSON_THROW_ON_ERROR );
		$isValid      = $tokenPayload['exp'] > time();


		return (object) [
			'isValid' => $isValid,
			'payload' => $tokenPayload
		];
	}
}
