<?php

namespace MintySupport\Classes\Modules\TemporarilyLogin\Actions;

use DateTime;
use MintySupport\Classes\Core\Managers\SettingsManager;
use MintySupport\Classes\Core\Wordpress\Action;

class TemporarilyLoginAction extends Action {

	public function getHooks(): array {
		return [
			'init',
		];
	}

	public function execute(): void {
		if ( empty( $_GET['token'] ) ) {
			return;
		}

		$token = sanitize_text_field( $_GET['token'] );
		$users = get_users( [
			'meta_key'   => 'auto_login_token',
			'meta_value' => $token,
			'number'     => 1,
		] );

		if ( empty( $users ) ) {
			return;
		}

		$user        = $users[0];
		$expireDate = get_user_meta( $user->ID, 'vervaldatum', true );

		// Controleer of de huidige datum voor of op de vervaldatum is
		if ( new DateTime() > new DateTime( $expireDate ) ) {
			// Het token is niet langer geldig omdat de vervaldatum is bereikt
			return;
		}

		// Als we hier zijn, is het token geldig en de vervaldatum niet bereikt
		// Veilig inloggen van de gebruiker
		wp_set_current_user( $user->ID );
		wp_set_auth_cookie( $user->ID );

		// Redirect naar de gewenste pagina na succesvolle login
		wp_redirect( admin_url() );
		exit;
	}
}