<?php

namespace MintySupport\Classes\Modules\TemporarilyLogin\AdminPages;

use MintySupport\Classes\Core\Managers\SettingsManager;
use MintySupport\Classes\Core\Settings\BaseAdminSettingsPage;


class TemporarilyLogin extends BaseAdminSettingsPage {
	public function getName(): string {
		return 'temporarily_login';
	}

	public function getSettingName(): string {
		return 'temp_login_enabled';
	}

	public function getDisplayName(): string {
		return 'Tijdelijke Login';
	}

	public function onLoad(): array {
		$settingsServices = SettingsManager::getInstance();

        $tempUsers = [];
        foreach (get_users() as $user) {
            if (!empty(get_user_meta( $user->ID, 'vervaldatum', true ))) {
                $tempUsers[$user->ID] = $user;
            }
        }

		return [
			"temp_login_enabled" => $settingsServices->getSettings('temp_login_enabled', false),
			'users' => $tempUsers,
			'roles' => wp_roles()->get_names(),
		];
	}

	public function saveTempUser(): bool {
		// Haal de waarden direct uit $_POST
		$userLogin  = $_POST['temp_login_name'];
		$userRole   = $_POST['temp_login_role'] ?? 'subscriber';
		$expireDate = $_POST['temp_login_expiredate'];

		// Controleer of de vereiste velden zijn ingevuld
		if ( empty( $userLogin ) || empty( $userRole ) || empty( $expireDate ) ) {
			echo '<div class="notice notice-error is-dismissible"><p>Alle velden moeten worden ingevuld. Controleer de invoer en probeer het opnieuw.</p></div>';

			return false;
		}

		// Controleer of gebruikersnaam al bestaat
		if ( username_exists( $userLogin ) ) {
			echo '<div class="notice notice-error is-dismissible"><p>Er is al een gebruiker met deze naam</p></div>';
			return false;
		}

		$userData = array(
			'user_login' => $userLogin,
			'user_pass'  => wp_generate_password(),
			'role'       => $userRole,
		);

		$userId = wp_insert_user( $userData );

		// Controleer op fouten
		if ( is_wp_error( $userId ) ) {
			echo '<div class="notice notice-error is-dismissible"><p>Fout bij het aanmaken van gebruiker: ' . $userId->get_error_message() . '</p></div>';
			return false;
		}

		// Voeg de vervaldatum toe als gebruikersmeta
		update_user_meta( $userId, 'vervaldatum', $expireDate );

		// Genereer een veiligheidstoken en sla dit op in de user_activation_key
		$autoLoginToken = wp_generate_password( 20, false );

		// Sla het token op als aangepaste gebruikersmeta
		update_user_meta( $userId, 'auto_login_token', $autoLoginToken );


		// Stel de auto-login URL samen
		$loginUrl = home_url('/auto-login?token=' . $autoLoginToken);

		// Toon de link
		echo '<div class="notice notice-success is-dismissible"><p>Gebruiker succesvol aangemaakt met ID: ' . $userId . '<br>' . esc_url($loginUrl) . '</p></div>';
		return true;
	}

	public function deleteTempUser(): bool {
		$userId = $_POST['temp_user_id'];

		// Controleer of de gebruiker bestaat
		if ( ! get_user_by( 'ID', $userId ) ) {
			echo '<div class="notice notice-error is-dismissible"><p>Gebruiker bestaat niet.</p></div>';
			return false;
		}

		// Verwijder de gebruiker
		wp_delete_user( $userId );

		echo '<div class="notice notice-success is-dismissible"><p>Gebruiker succesvol verwijderd.</p></div>';
		return true;
	}


	protected function getPostedSettings(): array {
		return [
			'temp_login_enabled',
			'temp_user_id',
		];
	}

	public function getOnSaveTrigger(): bool
	{
		return (!empty($_POST) && isset($_POST['action']) && ($_POST['action'] === 'save_minty_temp_user' || $_POST['action'] === 'save_minty_support_settings' || $_POST['action'] === 'delete_minty_temp_user'));
	}
}